Crate egide_storage_sqlite

Crate egide_storage_sqlite 

Egide Storage - SQLite Backend

SQLite implementation of the storage backend with tenant isolation. Each tenant gets its own database file for maximum security.

Structs

SqliteBackend
SQLite storage backend with tenant isolation.